# Generated by Django 2.2.12 on 2020-04-08 15:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('friendship', '0003_block_unique_together'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='block',
            options={'verbose_name': 'Blocked Relationship', 'verbose_name_plural': 'Blocked Relationships'},
        ),
    ]
